/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'basicstyles', 'nb', {
	bold: 'Fet',
	italic: 'Kursiv',
	strike: 'Gjennomstreking',
	subscript: 'Senket skrift',
	superscript: 'Hevet skrift',
	underline: 'Understreking'
} );
