{% if navigation %}
    <ul>
        {% for entry in navigation %}
            <li>
                <a{% if entry.here %} class="here"{% endif %} href="{{entry.url}}">{{entry.title}}</a>
            </li>
        {% endfor %}
    </ul>
{% endif %}
