/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'about', 'af', {
	copy: 'Kopiereg &copy; $1. Alle regte voorbehou.',
	dlgTitle: 'Meer oor CKEditor',
	help: 'Slaan $1 na vir hulp.',
	moreInfo: 'Vir lisensie-informasie, besoek asb. ons webwerf:',
	title: 'Meer oor CKEditor',
	userGuide: 'CKEditor Gebruikers gits'
} );
