/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'table', 'bg', {
	border: 'Размер на рамката',
	caption: 'Заглавие',
	cell: {
		menu: 'Клетка',
		insertBefore: 'Вмъкване на клетка преди',
		insertAfter: 'Вмъкване на клетка след',
		deleteCell: 'Изтриване на клетки',
		merge: 'Сливане на клетки',
		mergeRight: 'Сливане в дясно',
		mergeDown: 'Merge Down',
		splitHorizontal: 'Split Cell Horizontally',
		splitVertical: 'Split Cell Vertically',
		title: 'Настройки на клетката',
		cellType: 'Тип на клетката',
		rowSpan: 'Rows Span',
		colSpan: 'Columns Span',
		wordWrap: 'Авто. пренос',
		hAlign: 'Хоризонтално подравняване',
		vAlign: 'Вертикално подравняване',
		alignBaseline: 'Базова линия',
		bgColor: 'Фон',
		borderColor: 'Цвят на рамката',
		data: 'Данни',
		header: 'Хедър',
		yes: 'Да',
		no: 'Не',
		invalidWidth: 'Cell width must be a number.',
		invalidHeight: 'Cell height must be a number.',
		invalidRowSpan: 'Rows span must be a whole number.',
		invalidColSpan: 'Columns span must be a whole number.',
		chooseColor: 'Изберете'
	},
	cellPad: 'Отделяне на клетките',
	cellSpace: 'Разтояние между клетките',
	column: {
		menu: 'Колона',
		insertBefore: 'Вмъкване на колона преди',
		insertAfter: 'Вмъкване на колона след',
		deleteColumn: 'Изтриване на колони'
	},
	columns: 'Колони',
	deleteTable: 'Изтриване на таблица',
	headers: 'Хедъри',
	headersBoth: 'Заедно',
	headersColumn: 'Първа колона',
	headersNone: 'Няма',
	headersRow: 'Първи ред',
	invalidBorder: 'Размерът на рамката трябва да е число.',
	invalidCellPadding: 'Отстоянието на клетките трябва да е позитивно число.',
	invalidCellSpacing: 'Интервала в клетките трябва да е позитивно число.',
	invalidCols: 'Броят колони трябва да е по-голям от 0.',
	invalidHeight: 'Височината на таблицата трябва да е число.',
	invalidRows: 'Броят редове трябва да е по-голям от 0.',
	invalidWidth: 'Ширината на таблицата трябва да е число.',
	menu: 'Настройки на таблицата',
	row: {
		menu: 'Ред',
		insertBefore: 'Вмъкване на ред преди',
		insertAfter: 'Вмъкване на ред след',
		deleteRow: 'Изтриване на редове'
	},
	rows: 'Редове',
	summary: 'Обща информация',
	title: 'Настройки на таблицата',
	toolbar: 'Таблица',
	widthPc: 'процент',
	widthPx: 'пиксела',
	widthUnit: 'единица за ширина'
} );
