/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'toolbar', 'vi', {
	toolbarCollapse: 'Thu gọn thanh công cụ',
	toolbarExpand: 'Mở rộng thnah công cụ',
	toolbarGroups: {
		document: 'Tài liệu',
		clipboard: 'Clipboard/Undo',
		editing: 'Chỉnh sửa',
		forms: 'Bảng biểu',
		basicstyles: 'Kiểu cơ bản',
		paragraph: 'Đoạn',
		links: 'Liên kết',
		insert: 'Chèn',
		styles: 'Kiểu',
		colors: 'Màu sắc',
		tools: 'Công cụ'
	},
	toolbars: 'Thanh công cụ'
} );
