/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'toolbar', 'sv', {
	toolbarCollapse: 'Dölj verktygsfält',
	toolbarExpand: 'Visa verktygsfält',
	toolbarGroups: {
		document: 'Dokument',
		clipboard: 'Urklipp/ångra',
		editing: 'Redigering',
		forms: 'Formulär',
		basicstyles: 'Basstilar',
		paragraph: 'Paragraf',
		links: 'Länkar',
		insert: 'Infoga',
		styles: 'Stilar',
		colors: 'Färger',
		tools: 'Verktyg'
	},
	toolbars: 'Redigera verktygsfält'
} );
