/**
 * @license Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or http://ckeditor.com/license
 */

CKEDITOR.plugins.setLang( 'specialchar', 'sk', {
	euro: 'Znak eura',
	lsquo: 'Ľavá jednoduchá úvodzovka',
	rsquo: 'Pravá jednoduchá úvodzovka',
	ldquo: 'Pravá dvojitá úvodzovka',
	rdquo: 'Pravá dvojitá úvodzovka',
	ndash: 'En pomlčka',
	mdash: 'Em pomlčka',
	iexcl: 'Obrátený výkričník',
	cent: 'Znak centu',
	pound: 'Znak libry',
	curren: 'Znak meny',
	yen: 'Znak jenu',
	brvbar: 'Prerušená zvislá čiara',
	sect: 'Znak odseku',
	uml: 'Prehláska',
	copy: 'Znak copyrightu',
	ordf: 'Ženský indikátor rodu',
	laquo: 'Znak dvojitých lomených úvodzoviek vľavo',
	not: 'Logistický zápor',
	reg: 'Znak registrácie',
	macr: 'Pomlčka nad',
	deg: 'Znak stupňa',
	sup2: 'Dvojka ako horný index',
	sup3: 'Trojka ako horný index',
	acute: 'Dĺžeň',
	micro: 'Znak mikro',
	para: 'Znak odstavca',
	middot: 'Bodka uprostred',
	cedil: 'Chvost vľavo',
	sup1: 'Jednotka ako horný index',
	ordm: 'Mužský indikátor rodu',
	raquo: 'Znak dvojitých lomených úvodzoviek vpravo',
	frac14: 'Obyčajný zlomok jedna štvrtina',
	frac12: 'Obyčajný zlomok jedna polovica',
	frac34: 'Obyčajný zlomok tri štvrtiny',
	iquest: 'Otočený otáznik',
	Agrave: 'Veľké písmeno latinky A s accentom',
	Aacute: 'Veľké písmeno latinky A s dĺžňom',
	Acirc: 'Veľké písmeno latinky A s mäkčeňom',
	Atilde: 'Veľké písmeno latinky A s tildou',
	Auml: 'Veľké písmeno latinky A s dvoma bodkami',
	Aring: 'Veľké písmeno latinky A s krúžkom nad',
	AElig: 'Veľké písmeno latinky Æ',
	Ccedil: 'Veľké písmeno latinky C s chvostom vľavo',
	Egrave: 'Veľké písmeno latinky E s accentom',
	Eacute: 'Veľké písmeno latinky E s dĺžňom',
	Ecirc: 'Veľké písmeno latinky E s mäkčeňom',
	Euml: 'Veľké písmeno latinky E s dvoma bodkami',
	Igrave: 'Veľké písmeno latinky I s accentom',
	Iacute: 'Veľké písmeno latinky I s dĺžňom',
	Icirc: 'Veľké písmeno latinky I s mäkčeňom',
	Iuml: 'Veľké písmeno latinky I s dvoma bodkami',
	ETH: 'Veľké písmeno latinky Eth',
	Ntilde: 'Veľké písmeno latinky N s tildou',
	Ograve: 'Veľké písmeno latinky O s accentom',
	Oacute: 'Veľké písmeno latinky O s dĺžňom',
	Ocirc: 'Veľké písmeno latinky O s mäkčeňom',
	Otilde: 'Veľké písmeno latinky O s tildou',
	Ouml: 'Veľké písmeno latinky O s dvoma bodkami',
	times: 'Znak násobenia',
	Oslash: 'Veľké písmeno latinky O preškrtnuté',
	Ugrave: 'Veľké písmeno latinky U s accentom',
	Uacute: 'Veľké písmeno latinky U s dĺžňom',
	Ucirc: 'Veľké písmeno latinky U s mäkčeňom',
	Uuml: 'Veľké písmeno latinky U s dvoma bodkami',
	Yacute: 'Veľké písmeno latinky Y s dĺžňom',
	THORN: 'Veľké písmeno latinky Thorn',
	szlig: 'Malé písmeno latinky ostré s',
	agrave: 'Malé písmeno latinky a s accentom',
	aacute: 'Malé písmeno latinky a s dĺžňom',
	acirc: 'Malé písmeno latinky a s mäkčeňom',
	atilde: 'Malé písmeno latinky a s tildou',
	auml: 'Malé písmeno latinky a s dvoma bodkami',
	aring: 'Malé písmeno latinky a s krúžkom nad',
	aelig: 'Malé písmeno latinky æ',
	ccedil: 'Malé písmeno latinky c s chvostom vľavo',
	egrave: 'Malé písmeno latinky e s accentom',
	eacute: 'Malé písmeno latinky e s dĺžňom',
	ecirc: 'Malé písmeno latinky e s mäkčeňom',
	euml: 'Malé písmeno latinky e s dvoma bodkami',
	igrave: 'Malé písmeno latinky i s accentom',
	iacute: 'Malé písmeno latinky i s dĺžňom',
	icirc: 'Malé písmeno latinky i s mäkčeňom',
	iuml: 'Malé písmeno latinky i s dvoma bodkami',
	eth: 'Malé písmeno latinky eth',
	ntilde: 'Malé písmeno latinky n s tildou',
	ograve: 'Malé písmeno latinky o s accentom',
	oacute: 'Malé písmeno latinky o s dĺžňom',
	ocirc: 'Malé písmeno latinky o s mäkčeňom',
	otilde: 'Malé písmeno latinky o s tildou',
	ouml: 'Malé písmeno latinky o s dvoma bodkami',
	divide: 'Znak delenia',
	oslash: 'Malé písmeno latinky o preškrtnuté',
	ugrave: 'Malé písmeno latinky u s accentom',
	uacute: 'Malé písmeno latinky u s dĺžňom',
	ucirc: 'Malé písmeno latinky u s mäkčeňom',
	uuml: 'Malé písmeno latinky u s dvoma bodkami',
	yacute: 'Malé písmeno latinky y s dĺžňom',
	thorn: 'Malé písmeno latinky thorn',
	yuml: 'Malé písmeno latinky y s dvoma bodkami',
	OElig: 'Veľká ligatúra latinky OE',
	oelig: 'Malá ligatúra latinky OE',
	'372': 'Veľké písmeno latinky W s mäkčeňom',
	'374': 'Veľké písmeno latinky Y s mäkčeňom',
	'373': 'Malé písmeno latinky w s mäkčeňom',
	'375': 'Malé písmeno latinky y s mäkčeňom',
	sbquo: 'Dolná jednoduchá 9-úvodzovka',
	'8219': 'Horná jednoduchá otočená 9-úvodzovka',
	bdquo: 'Dolná dvojitá 9-úvodzovka',
	hellip: 'Trojbodkový úvod',
	trade: 'Znak ibchodnej značky',
	'9658': 'Čierny ukazovateľ smerujúci vpravo',
	bull: 'Kruh',
	rarr: 'Šípka vpravo',
	rArr: 'Dvojitá šipka vpravo',
	hArr: 'Dvojitá šipka vľavo a vpravo',
	diams: 'Čierne piky',
	asymp: 'Skoro sa rovná'
} );
