/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'about', 'ka', {
	copy: 'Copyright &copy; $1. ყველა უფლება დაცულია.',
	dlgTitle: 'CKEditor-ის შესახებ',
	help: 'დახმარებისთვის იხილეთ $1.',
	moreInfo: 'ლიცენზიის ინფორმაციისთვის ეწვიეთ ჩვენს საიტს:',
	title: 'CKEditor-ის შესახებ',
	userGuide: 'CKEditor-ის მომხმარებლის სახელმძღვანელო'
} );
