/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'pastefromword', 'sk', {
	confirmCleanup: 'Vkladaný text vyzerá byť skopírovaný z Wordu. Chcete ho automaticky vyčistiť pred vkladaním?',
	error: 'Nebolo možné vyčistiť vložené dáta kvôli internej chybe',
	title: 'Vložiť z Wordu',
	toolbar: 'Vložiť z Wordu'
} );
