/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'format', 'ja', {
	label: '書式',
	panelTitle: '段落の書式',
	tag_address: 'アドレス',
	tag_div: '標準 (DIV)',
	tag_h1: '見出し 1',
	tag_h2: '見出し 2',
	tag_h3: '見出し 3',
	tag_h4: '見出し 4',
	tag_h5: '見出し 5',
	tag_h6: '見出し 6',
	tag_p: '標準',
	tag_pre: '書式付き'
} );
