/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'toolbar', 'da', {
	toolbarCollapse: 'Sammenklap værktøjslinje',
	toolbarExpand: 'Udvid værktøjslinje',
	toolbarGroups: {
		document: 'Dokument',
		clipboard: 'Udklipsholder/Fortryd',
		editing: 'Redigering',
		forms: 'Formularer',
		basicstyles: 'Basis styles',
		paragraph: 'Paragraf',
		links: 'Links',
		insert: 'Indsæt',
		styles: 'Typografier',
		colors: 'Farver',
		tools: 'Værktøjer'
	},
	toolbars: 'Editors værktøjslinjer'
} );
