/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'basicstyles', 'el', {
	bold: 'Έντονη',
	italic: 'Πλάγια',
	strike: 'Διακριτή Διαγραφή',
	subscript: 'Δείκτης',
	superscript: 'Εκθέτης',
	underline: 'Υπογράμμιση'
} );
