/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'hu', {
	acccessKey: 'Billentyűkombináció',
	advanced: 'További opciók',
	advisoryContentType: 'Súgó tartalomtípusa',
	advisoryTitle: 'Súgócimke',
	anchor: {
		toolbar: 'Horgony beillesztése/szerkesztése',
		menu: 'Horgony tulajdonságai',
		title: 'Horgony tulajdonságai',
		name: 'Horgony neve',
		errorName: 'Kérem adja meg a horgony nevét',
		remove: 'Horgony eltávolítása'
	},
	anchorId: 'Azonosító szerint',
	anchorName: 'Horgony név szerint',
	charset: 'Hivatkozott tartalom kódlapja',
	cssClasses: 'Stíluskészlet',
	emailAddress: 'E-Mail cím',
	emailBody: 'Üzenet',
	emailSubject: 'Üzenet tárgya',
	id: 'Id',
	info: 'Alaptulajdonságok',
	langCode: 'Írás iránya',
	langDir: 'Írás iránya',
	langDirLTR: 'Balról jobbra',
	langDirRTL: 'Jobbról balra',
	menu: 'Hivatkozás módosítása',
	name: 'Név',
	noAnchors: '(Nincs horgony a dokumentumban)',
	noEmail: 'Adja meg az E-Mail címet',
	noUrl: 'Adja meg a hivatkozás webcímét',
	other: '<más>',
	popupDependent: 'Szülőhöz kapcsolt (csak Netscape)',
	popupFeatures: 'Felugró ablak jellemzői',
	popupFullScreen: 'Teljes képernyő (csak IE)',
	popupLeft: 'Bal pozíció',
	popupLocationBar: 'Címsor',
	popupMenuBar: 'Menü sor',
	popupResizable: 'Átméretezés',
	popupScrollBars: 'Gördítősáv',
	popupStatusBar: 'Állapotsor',
	popupToolbar: 'Eszköztár',
	popupTop: 'Felső pozíció',
	rel: 'Kapcsolat típusa',
	selectAnchor: 'Horgony választása',
	styles: 'Stílus',
	tabIndex: 'Tabulátor index',
	target: 'Tartalom megjelenítése',
	targetFrame: '<keretben>',
	targetFrameName: 'Keret neve',
	targetPopup: '<felugró ablakban>',
	targetPopupName: 'Felugró ablak neve',
	title: 'Hivatkozás tulajdonságai',
	toAnchor: 'Horgony az oldalon',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toolbar: 'Hivatkozás beillesztése/módosítása',
	type: 'Hivatkozás típusa',
	unlink: 'Hivatkozás törlése',
	upload: 'Feltöltés'
} );
