/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'specialchar', 'bg', {
	options: 'Опции за специален знак',
	title: 'Избор на специален знак',
	toolbar: 'Вмъкване на специален знак'
} );
