/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'is', {
	acccessKey: 'Skammvalshnappur',
	advanced: 'Tæknilegt',
	advisoryContentType: 'Tegund innihalds',
	advisoryTitle: 'Titill',
	anchor: {
		toolbar: 'Stofna/breyta kaflamerki',
		menu: 'Eigindi kaflamerkis',
		title: 'Eigindi kaflamerkis',
		name: 'Nafn bókamerkis',
		errorName: 'Sláðu inn nafn bókamerkis!',
		remove: 'Remove Anchor'
	},
	anchorId: 'Eftir auðkenni einingar',
	anchorName: 'Eftir akkerisnafni',
	charset: 'Táknróf',
	cssClasses: 'Stílsniðsflokkur',
	emailAddress: 'Netfang',
	emailBody: 'Meginmál',
	emailSubject: 'Efni',
	id: 'Auðkenni',
	info: 'Almennt',
	langCode: 'Lesstefna',
	langDir: 'Lesstefna',
	langDirLTR: 'Frá vinstri til hægri (LTR)',
	langDirRTL: 'Frá hægri til vinstri (RTL)',
	menu: 'Breyta stiklu',
	name: 'Nafn',
	noAnchors: '<Engin bókamerki á skrá>',
	noEmail: 'Sláðu inn netfang!',
	noUrl: 'Sláðu inn veffang stiklunnar!',
	other: '<annar>',
	popupDependent: 'Háð venslum (Netscape)',
	popupFeatures: 'Eigindi sprettiglugga',
	popupFullScreen: 'Heilskjár (IE)',
	popupLeft: 'Fjarlægð frá vinstri',
	popupLocationBar: 'Fanglína',
	popupMenuBar: 'Vallína',
	popupResizable: 'Resizable', // MISSING
	popupScrollBars: 'Skrunstikur',
	popupStatusBar: 'Stöðustika',
	popupToolbar: 'Verkfærastika',
	popupTop: 'Fjarlægð frá efri brún',
	rel: 'Relationship', // MISSING
	selectAnchor: 'Veldu akkeri',
	styles: 'Stíll',
	tabIndex: 'Raðnúmer innsláttarreits',
	target: 'Mark',
	targetFrame: '<rammi>',
	targetFrameName: 'Nafn markglugga',
	targetPopup: '<sprettigluggi>',
	targetPopupName: 'Nafn sprettiglugga',
	title: 'Stikla',
	toAnchor: 'Bókamerki á þessari síðu',
	toEmail: 'Netfang',
	toUrl: 'Vefslóð',
	toolbar: 'Stofna/breyta stiklu',
	type: 'Stikluflokkur',
	unlink: 'Fjarlægja stiklu',
	upload: 'Senda upp'
} );
