/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'toolbar', 'tt', {
	toolbarCollapse: 'Collapse Toolbar', // MISSING
	toolbarExpand: 'Expand Toolbar', // MISSING
	toolbarGroups: {
		document: 'Документ',
		clipboard: 'Алмашу буферы/Кайтару',
		editing: 'Төзәтү',
		forms: 'Формалар',
		basicstyles: 'Төп стильләр',
		paragraph: 'Параграф',
		links: 'Сылталамалар',
		insert: 'Өстәү',
		styles: 'Стильләр',
		colors: 'Төсләр',
		tools: 'Кораллар'
	},
	toolbars: 'Editor toolbars' // MISSING
} );
