/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'pastetext', 'da', {
	button: 'Indsæt som ikke-formateret tekst',
	title: 'Indsæt som ikke-formateret tekst'
} );
