/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'pastefromword', 'eu', {
	confirmCleanup: 'Itsatsi nahi duzun testua Wordetik hartua dela dirudi. Itsatsi baino lehen garbitu nahi duzu?',
	error: 'Barneko errore bat dela eta ezin izan da testua garbitu',
	title: 'Itsatsi Word-etik',
	toolbar: 'Itsatsi Word-etik'
} );
