/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'toolbar', 'ru', {
	toolbarCollapse: 'Свернуть панель инструментов',
	toolbarExpand: 'Развернуть панель инструментов',
	toolbarGroups: {
		document: 'Документ',
		clipboard: 'Буфер обмена / Отмена действий',
		editing: 'Корректировка',
		forms: 'Формы',
		basicstyles: 'Простые стили',
		paragraph: 'Абзац',
		links: 'Ссылки',
		insert: 'Вставка',
		styles: 'Стили',
		colors: 'Цвета',
		tools: 'Инструменты'
	},
	toolbars: 'Панели инструментов редактора'
} );
