/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'fakeobjects', 'lv', {
	anchor: 'Iezīme',
	flash: 'Flash animācija',
	hiddenfield: 'Slēpts lauks',
	iframe: 'Iframe',
	unknown: 'Nezināms objekts'
} );
