/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'about', 'ko', {
	copy: '저작권 &copy; $1 . 판권 소유.',
	dlgTitle: 'CKEditor 에 대하여',
	help: '도움이 필요하시면 $1 를 확인하세요.',
	moreInfo: '라이선스에 대한 정보는 저희 웹 사이트를 참고하세요:',
	title: 'CKEditor에 대하여',
	userGuide: 'CKEditor 사용설명서'
} );
