/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'about', 'id', {
	copy: 'Hak cipta &copy; $1. All rights reserved.',
	dlgTitle: 'Tentang CKEditor',
	help: 'Cel $1 untuk bantuan.',
	moreInfo: 'Untuk informasi lisensi silahkan kunjungi web site kami:',
	title: 'Tentang CKEditor',
	userGuide: 'Petunjuk Pengguna CKEditor'
} );
