/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'toolbar', 'gu', {
	toolbarCollapse: 'ટૂલબાર નાનું કરવું',
	toolbarExpand: 'ટૂલબાર મોટું કરવું',
	toolbarGroups: {
		document: 'દસ્તાવેજ',
		clipboard: 'ક્લિપબોર્ડ/અન',
		editing: 'એડીટ કરવું',
		forms: 'ફોર્મ',
		basicstyles: 'બેસિક્ સ્ટાઇલ',
		paragraph: 'ફકરો',
		links: 'લીંક',
		insert: 'ઉમેરવું',
		styles: 'સ્ટાઇલ',
		colors: 'રંગ',
		tools: 'ટૂલ્સ'
	},
	toolbars: 'એડીટર ટૂલ બાર'
} );
