/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'toolbar', 'gl', {
	toolbarCollapse: 'Contraer a barra de ferramentas',
	toolbarExpand: 'Expandir a barra de ferramentas',
	toolbarGroups: {
		document: 'Documento',
		clipboard: 'Portapapeis/desfacer',
		editing: 'Edición',
		forms: 'Formularios',
		basicstyles: 'Estilos básicos',
		paragraph: 'Paragrafo',
		links: 'Ligazóns',
		insert: 'Inserir',
		styles: 'Estilos',
		colors: 'Cores',
		tools: 'Ferramentas'
	},
	toolbars: 'Barras de ferramentas do editor'
} );
