/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'format', 'km', {
	label: 'ទម្រង់',
	panelTitle: 'ទម្រង់​កថាខណ្ឌ',
	tag_address: 'អាសយដ្ឋាន',
	tag_div: 'ធម្មតា (DIV)',
	tag_h1: 'ចំណង​ជើង 1',
	tag_h2: 'ចំណង​ជើង 2',
	tag_h3: 'ចំណង​ជើង 3',
	tag_h4: 'ចំណង​ជើង 4',
	tag_h5: 'ចំណង​ជើង 5',
	tag_h6: 'ចំណង​ជើង 6',
	tag_p: 'ធម្មតា',
	tag_pre: 'Formatted' // MISSING
} );
