/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'image', 'vi', {
	alt: 'Chú thích ảnh',
	border: 'Đường viền',
	btnUpload: 'Tải lên máy chủ',
	button2Img: 'Bạn có muốn chuyển nút bấm bằng ảnh được chọn thành ảnh?',
	hSpace: 'Khoảng đệm ngang',
	img2Button: 'Bạn có muốn chuyển đổi ảnh được chọn thành nút bấm bằng ảnh?',
	infoTab: 'Thông tin của ảnh',
	linkTab: 'Tab liên kết',
	lockRatio: 'Giữ nguyên tỷ lệ',
	menu: 'Thuộc tính của ảnh',
	resetSize: 'Kích thước gốc',
	title: 'Thuộc tính của ảnh',
	titleButton: 'Thuộc tính nút của ảnh',
	upload: 'Tải lên',
	urlMissing: 'Thiếu đường dẫn hình ảnh',
	vSpace: 'Khoảng đệm dọc',
	validateBorder: 'Chiều rộng của đường viền phải là một số nguyên dương',
	validateHSpace: 'Khoảng đệm ngang phải là một số nguyên dương',
	validateVSpace: 'Khoảng đệm dọc phải là một số nguyên dương'
} );
