/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'indent', 'fr-ca', {
	indent: 'Augmenter le retrait',
	outdent: 'Diminuer le retrait'
} );
