/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'fakeobjects', 'sr', {
	anchor: 'Anchor', // MISSING
	flash: 'Flash Animation', // MISSING
	hiddenfield: 'Hidden Field', // MISSING
	iframe: 'IFrame', // MISSING
	unknown: 'Unknown Object' // MISSING
} );
