/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'pastefromword', 'fi', {
	confirmCleanup: 'Liittämäsi teksti näyttäisi olevan Word-dokumentista. Haluatko siivota sen ennen liittämistä? (Suositus: Kyllä)',
	error: 'Liitetyn tiedon siivoaminen ei onnistunut sisäisen virheen takia',
	title: 'Liitä Word-dokumentista',
	toolbar: 'Liitä Word-dokumentista'
} );
